// The following ifdef block is the standard way of creating macros which make exporting 
// from a DLL simpler. All files within this DLL are compiled with the DHHALLIB_EXPORTS
// symbol defined on the command line. this symbol should not be defined on any project
// that uses this DLL. This way any other project whose source files include this file see 
// DHHALLIB_API functions as being imported from a DLL, whereas this DLL sees symbols
// defined with this macro as being exported.

/*
// Copyright (c) DH electronics GmbH.  All rights reserved.
//
//------------------------------------------------------------------------------
//
//  File: DHHalLib.h
//
//  Version:  1.0.0.0
//
//  Abstract: Declaration of the public functions of the DHHalLib.dll.
//
//  Notes:
//		Created by: 	Andreas Geisreiter
//  	Created: 		September 06, 2012
//		Modified by:	Christian Apfel
//		Modified:		December 07, 2015
//
//----------------------------------------------------------------------------*/


#ifndef DHHALLIB_H
#define DHHALLIB_H

//#ifdef cplusplus
#ifdef DHHALLIB_EXPORTS
#define DHHALLIB_API extern "C"  __declspec(dllexport)
#else
#define DHHALLIB_API extern "C" __declspec(dllimport)
#endif
//#else
//#ifdef DHHALLIB_EXPORTS
//#define DHHALLIB_API __declspec(dllexport);
//#else
//#define DHHALLIB_API __declspec(dllimport);
//#endif
//#endif



typedef enum DHCOM_GPIOEnum
{
   DHCOM_GPIO_A=1,
   DHCOM_GPIO_B,
   DHCOM_GPIO_C,
   DHCOM_GPIO_D,
   DHCOM_GPIO_E,
   DHCOM_GPIO_F,
   DHCOM_GPIO_G,
   DHCOM_GPIO_H,
   DHCOM_GPIO_I,
   DHCOM_GPIO_J,
   DHCOM_GPIO_K,
   DHCOM_GPIO_L,
   DHCOM_GPIO_M,
   DHCOM_GPIO_N,
   DHCOM_GPIO_O,
   DHCOM_GPIO_P,
   DHCOM_GPIO_Q,
   DHCOM_GPIO_R,
   DHCOM_GPIO_S,
   DHCOM_GPIO_T,
   DHCOM_GPIO_U,
   DHCOM_GPIO_V,
   DHCOM_GPIO_W,
   DHCOM_GPIO_UART1_CTS,
   DHCOM_GPIO_UART1_RTS,
   DHCOM_GPIO_UART2_CTS,
   DHCOM_GPIO_UART2_RTS,
   DHCOM_GPIO_UART3_CTS,
   DHCOM_GPIO_UART3_RTS,
   DHCOM_GPIO_UART4_CTS,
   DHCOM_GPIO_UART4_RTS,
   DHCOM_GPIO_UART5_CTS,
   DHCOM_GPIO_UART5_RTS,
   DHCOM_GPIO_NOT_DEFINED
}*pDHCOM_GPIOEnum;

typedef enum GPIOConvertType
{
	DHCOM_GPIO_ID=0,
	DHCOM_GPIO_PORT,
	DHCOM_GPIO_PIN
}*pGPIOConvertType;

typedef enum DHCOM_I2CEnum
{
	DHCOM_I2C0=0,
	DHCOM_I2C1,
	DHCOM_I2C2,
	DHCOM_I2C3,
	/*DHCOM_I2C4,*/
	DHCOM_I2C_NOT_DEFINED
}*pDHCOM_I2CEnum;

typedef enum DHCOM_I2CFREQMode
{
	I2C_100K=0,
	I2C_400K,
	I2C_800K,
	I2C_1600K,
	I2C_2400K,
	I2C_3200K
}*pDHCOM_I2CFREQMode;

//------------------------------------------------------------------------------
// Defines
//------------------------------------------------------------------------------
#define BSP_VERSION_NUMBER				TEXT("BSPVersionNumber")
#define BSP_VERSION_REG_PATH			TEXT("Ident")
#define WINCE_IMAGE_VERSION_NUMBER		TEXT("ImageVersionNumber")
#define WINCE_IMAGE_VERSION_REG_PATH	TEXT("Ident")

//------------------------------------------------------------------------------
// Private functions of the DHHalLib.dll
//------------------------------------------------------------------------------
// Convert Gpio Pin
DWORD ConvertGPIO(DHCOM_GPIOEnum eDHCOMGpio, GPIOConvertType eGPIOType);

//------------------------------------------------------------------------------
// Exported functions of the DHHalLib.dll
//------------------------------------------------------------------------------
// Version Numbers
// ---------------
// Returns the DHHalLib Version
DHHALLIB_API unsigned long DHHalLibGetVersion();
// Returns the BWP Version Version
DHHALLIB_API unsigned long BSPGetVersion();
// Returns the WinCE Image Version
DHHALLIB_API unsigned long WinCEImageGetVersion();

// GPIO
// ----
// Sets the GPIO Pin direction
DHHALLIB_API bool GPIOSetDirection(DHCOM_GPIOEnum eGpio, bool bInOut, bool bDefaultState);
// Sets the GPIO Pin state
DHHALLIB_API void GPIOSetPin(DHCOM_GPIOEnum eGpio, bool bState);
// Returns the current GPIO Pin state
DHHALLIB_API bool GPIOGetPin(DHCOM_GPIOEnum eGpio);
// Set the GPIO Pin Single Interrupt
//DHHALLIB_API bool GPIOSetSingleEvent(DHCOM_GPIOEnum eGpio, HANDLE *hEvent, long lTimeout);
// Set the GPIO Pin Permanent Interrupt
DHHALLIB_API bool GPIOSetInterrupt(DHCOM_GPIOEnum eGpio, HANDLE *hEvent, unsigned long ulTimeout);
// Clear the GPIO Pin Interrupt
DHHALLIB_API bool GPIOClearInterrupt(DHCOM_GPIOEnum eGpio);

// I2C
// ---
// Open I2C port
DHHALLIB_API bool I2COpen(DHCOM_I2CEnum eI2CPort, DHCOM_I2CFREQMode eI2CFreq);
// Close I2C port
DHHALLIB_API void I2CClose(DHCOM_I2CEnum eI2CPort);
// Read 1 Byte from I2C device
DHHALLIB_API bool I2CRead(DHCOM_I2CEnum eI2CPort, DHCOM_I2CFREQMode eI2CFreq, unsigned char cDevId, unsigned char cI2CReg, unsigned char *pOutBuffer);
// Read multiple Bytes from I2C device
DHHALLIB_API bool I2CReadMultipleBytes(DHCOM_I2CEnum eI2CPort, DHCOM_I2CFREQMode eI2CFreq, unsigned char cDevId, unsigned char cI2CReg, unsigned char cBytes, unsigned char *pOutBuffer);
// Write 1 Byte to I2C device
DHHALLIB_API bool I2CWrite(DHCOM_I2CEnum eI2CPort, DHCOM_I2CFREQMode eI2CFreq, unsigned char cDevId, unsigned char cI2CReg, unsigned char cValue);
// Write multiple Bytes to I2C device
DHHALLIB_API bool I2CWriteMultipleBytes(DHCOM_I2CEnum eI2CPort, DHCOM_I2CFREQMode eI2CFreq, unsigned char cDevId, unsigned char cI2CReg, unsigned char cBytes, unsigned char *pInBuffer);

// Memory
// ------
// Writes value to specified phy. address
DHHALLIB_API int WritePhysicalAddress(int iPhyAddr, unsigned char cRegSize, int iValue, bool bReadBack);
// Read from the specified phy. address
DHHALLIB_API int ReadPhysicalAddress(int iPhyAddr, unsigned char cRegSize);

// KITL Control
// ------------
// Restart KITL Connection Power
DHHALLIB_API bool RestartPowerKITL();
// Control KITL Connection Power
DHHALLIB_API bool ControlPowerKITL(bool bEnable);

// PWM
// ------
// Set DHCOM Backlight Level
DHHALLIB_API bool SetBacklightLevel(int iLevel);
// Set DHCOM Backlight Suspend
DHHALLIB_API bool SetBacklightSuspend(int Timeout, bool bEnable);

// Touch Screen
// ------------
// Start's the Touch Screen Calibration
DHHALLIB_API bool CalibrateTouch();	
// Clear's the Touch Calibration data
DHHALLIB_API bool ClearTouchCalibrationData();

// Watchdog & Reset
// ----------------
// Performs a software reset
DHHALLIB_API void SoftReset();	

// Registry
// --------
// Stores the registry permanent
DHHALLIB_API bool SaveRegistry();
// Creates Registry backup files on Storage Card
DHHALLIB_API bool CreateRegistryBackup();
// Restores Registry backup files from Storage Card and restarts CPU
DHHALLIB_API bool RestoreRegistryBackup();

#endif
